@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP11;
 use vars '$VERSION';
-$VERSION = '2.17';
+$VERSION = '2.18';
 
 use base 'XML::Compile::SOAP';
 
@@ -128,6 +128,7 @@ sub _sender(@)
     {   error __x"mustUnderstand for unknown header {headers}"
           , headers => [keys %understand];
     }
+
     if(keys %destination)
     {   error __x"destination for unknown header {headers}"
           , headers => [keys %destination];
@@ -243,9 +244,6 @@ sub _reader_faults($$)
     sub
     {   my $data   = shift;
         my $faults  = $data->{Fault}    or return;
-        my $details = $faults->{detail} or return;
-        my $dettype = delete $details->{_ELEMENT_ORDER};
-        $dettype && @$dettype or return $data;
 
         my ($code_ns, $code_err) = unpack_type $faults->{faultcode};
         my ($err, @sub_err) = split /\./, $code_err;
@@ -261,9 +259,14 @@ sub _reader_faults($$)
         $nice{role} = $self->roleAbbreviation($faults->{faultactor})
             if $faults->{faultactor};
 
+        my $details = $faults->{detail};
+        my $dettype = $details ? delete $details->{_ELEMENT_ORDER} : undef;
+
         my $name;
-        if($name = $names{$dettype->[0]})
+        if(!$details) { $name = 'error' }
+        elsif(@$dettype && $names{$dettype->[0]})
         {   # fault named in WSDL
+            $name = $names{$dettype->[0]};
             if(keys %$details==1)
             {   my (undef, $v) = %$details;
                 @nice{keys %$v} = values %$v;
